"use strict";

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@testing-library/react");

var _checkVisibility = _interopRequireDefault(require("./checkVisibility"));

var _ = _interopRequireDefault(require("."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

jest.mock('./checkVisibility');
var addEventListenerSpy = jest.spyOn(window, 'addEventListener');

var Foo = function Foo(_ref) {
  var partial = _ref.partial,
      scrollableEl = _ref.scrollableEl;
  var elRef = (0, _react.useRef)(null);
  var isVisible = (0, _["default"])(elRef.current, {
    partial: partial,
    scrollableEl: scrollableEl
  });
  return _react["default"].createElement("div", {
    ref: elRef
  }, isVisible ? 'visible' : 'not visible');
};

describe('useVisibility', function () {
  test('is initially not visible', function () {
    var _render = (0, _react2.render)(_react["default"].createElement(Foo, null)),
        container = _render.container;

    var el = container.firstChild;
    expect(el).toHaveTextContent('not visible');
  });
  test('attaches scroll and resize event listeners to window', function () {
    var _render2 = (0, _react2.render)(_react["default"].createElement(Foo, null)),
        rerender = _render2.rerender; // Force useEffect to run.


    rerender(_react["default"].createElement(Foo, null));
    expect(addEventListenerSpy).toHaveBeenCalledWith('scroll', expect.any(Function));
    expect(addEventListenerSpy).toHaveBeenCalledWith('resize', expect.any(Function));
  });
  test('updates visibility after component is rendered', function () {
    var _render3 = (0, _react2.render)(_react["default"].createElement(Foo, null)),
        container = _render3.container,
        rerender = _render3.rerender;

    var el = container.firstChild;
    expect(el).toHaveTextContent('not visible');

    _checkVisibility["default"].mockReturnValue(true); // Force useEffect to run.


    rerender(_react["default"].createElement(Foo, null));
    expect(el).toHaveTextContent('visible');
    expect(_checkVisibility["default"]).toHaveBeenCalledWith(el, false);
  });
  test.skip('updates visibility on window scroll', function () {});
  test.skip('updates visibility on window resize', function () {});
  describe('with partial option', function () {
    test('checks partial visibility', function () {
      var _render4 = (0, _react2.render)(_react["default"].createElement(Foo, {
        partial: true
      })),
          container = _render4.container,
          rerender = _render4.rerender;

      var el = container.firstChild; // Force useEffect to run.

      rerender(_react["default"].createElement(Foo, {
        partial: true
      }));
      expect(_checkVisibility["default"]).toHaveBeenCalledWith(el, true);
    });
  });
  describe('with scrollableEl option', function () {
    test('attaches scroll event listener to passed in scrollable element', function () {
      var scrollableEl = {
        addEventListener: jest.fn(),
        removeEventListener: jest.fn()
      };

      var _render5 = (0, _react2.render)(_react["default"].createElement(Foo, {
        scrollableEl: scrollableEl
      })),
          rerender = _render5.rerender; // Force useEffect to run.


      rerender(_react["default"].createElement(Foo, null));
      expect(scrollableEl.addEventListener).toHaveBeenCalledWith('scroll', expect.any(Function));
    });
  });
});